pub(crate) enum ClipboardEventType {
Change,
Copy,
Cut,
Paste,
Other(Atom),
}Expand description
The types of clipboard events in the Clipboard APIs specification: https://www.w3.org/TR/clipboard-apis/#clipboard-actions.
Variants
Implementations
Sourceimpl ClipboardEventType
impl ClipboardEventType
Sourcepub(crate) fn as_atom(&self) -> Atom
pub(crate) fn as_atom(&self) -> Atom
Convert this ClipboardEventType to an Atom for use in creating DOM events.